==> upload-api-client-internal-1.109.1.tgz: package/src/services/FilesService.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { BeginUploadRequest } from "../models/BeginUploadRequest";
import type { BeginUploadResponse } from "../models/BeginUploadResponse";
import type { CompleteUploadPartRequest } from "../models/CompleteUploadPartRequest";
import type { ContinuationToken } from "../models/ContinuationToken";
import type { DeleteFileBatch } from "../models/DeleteFileBatch";
import type { FileId } from "../models/FileId";
import type { FileSummary } from "../models/FileSummary";
import type { FileTagName } from "../models/FileTagName";
import type { FileTagPrefixSearch } from "../models/FileTagPrefixSearch";
import type { PageSize } from "../models/PageSize";
import type { Paginated_FileSummary_ } from "../models/Paginated_FileSummary_";
import type { UploadPart } from "../models/UploadPart";
import type { UploadPartIndex } from "../models/UploadPartIndex";
import type { UploadPartList } from "../models/UploadPartList";
import { request as __request } from "../core/request";

export class FilesService {
  /**
   * Begins a new multipart file upload. Required API key type: 'secret_*' or 'public_*'.
   * @param requestBody File upload parameters.
   * @returns BeginUploadResponse Success.
   * @throws ApiError
   */
  public static async beginMultipartUpload(requestBody: BeginUploadRequest): Promise<BeginUploadResponse> {
    const result = await __request({
      method: "POST",
      path: `/v1/files`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Deletes multiple files. Required API key type: 'secret_*' only.
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async deleteFileBatch(requestBody: DeleteFileBatch): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/files`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Lists the files for a given account. Required API key type: 'secret_*' only.
   * @param accountId
   * @param pageSize
   * @param fileTag
   * @param fileTagPrefixSearch
   * @param backwardToken
   * @param forwardToken
   * @returns Paginated_FileSummary_ Success.
   * @throws ApiError
   */
  public static async getFiles(
    accountId: AccountId,
    pageSize: PageSize,
    fileTag?: FileTagName,
    fileTagPrefixSearch?: FileTagPrefixSearch,
    backwardToken?: ContinuationToken,
    forwardToken?: ContinuationToken
  ): Promise<Paginated_FileSummary_> {
    const result = await __request({
      method: "GET",
      path: `/v1/files`,
      query: {
        accountId: accountId,
        pageSize: pageSize,
        fileTag: fileTag,
        fileTagPrefixSearch: fileTagPrefixSearch,
        backwardToken: backwardToken,
        forwardToken: forwardToken
      },
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Finalizes an upload part for an in-progress multipart upload. Required API key type: 'secret_*' or 'public_*'.
   * @param fileId
   * @param uploadPartIndex
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async completeUploadPart(
    fileId: FileId,
    uploadPartIndex: UploadPartIndex,
    requestBody: CompleteUploadPartRequest
  ): Promise<void> {
    const result = await __request({
      method: "PUT",
      path: `/v1/files/${fileId}/upload_parts/${uploadPartIndex}`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File or upload part not found.`
      }
    });
    return result.body;
  }

  /**
   * Gets a remaining upload part for an in-progress upload. Required API key type: 'secret_*' or 'public_*'.
   * @param fileId
   * @param uploadPartIndex
   * @returns UploadPart Success.
   * @throws ApiError
   */
  public static async getUploadPart(fileId: FileId, uploadPartIndex: UploadPartIndex): Promise<UploadPart> {
    const result = await __request({
      method: "GET",
      path: `/v1/files/${fileId}/upload_parts/${uploadPartIndex}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File or upload part not found.`
      }
    });
    return result.body;
  }

  /**
   * Deletes a single file. Required API key type: 'secret_*' only.
   * @param fileId
   * @returns void
   * @throws ApiError
   */
  public static async deleteFile(fileId: FileId): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/files/${fileId}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Gets information about a specific file. Required API key type: 'secret_*' only.
   * @param fileId
   * @returns FileSummary Success.
   * @throws ApiError
   */
  public static async getFile(fileId: FileId): Promise<FileSummary> {
    const result = await __request({
      method: "GET",
      path: `/v1/files/${fileId}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Lists the remaining upload parts for an in-progress upload. An empty array is returned when the upload is complete. Required API key type: 'secret_*' or 'public_*'.
   * @param fileId
   * @returns UploadPartList Success.
   * @throws ApiError
   */
  public static async getUploadParts(fileId: FileId): Promise<UploadPartList> {
    const result = await __request({
      method: "GET",
      path: `/v1/files/${fileId}/upload_parts`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File not found.`
      }
    });
    return result.body;
  }
}

==> upload-api-client-internal-1.126.0.tgz: package/src/services/FilesService.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { AccountId } from "../models/AccountId";
import type { BeginUploadRequest } from "../models/BeginUploadRequest";
import type { BeginUploadResponse } from "../models/BeginUploadResponse";
import type { CompleteUploadPartRequest } from "../models/CompleteUploadPartRequest";
import type { ContinuationToken } from "../models/ContinuationToken";
import type { DeleteFileBatch } from "../models/DeleteFileBatch";
import type { FileId } from "../models/FileId";
import type { FileSummaryExtended } from "../models/FileSummaryExtended";
import type { FileTagName } from "../models/FileTagName";
import type { FileTagPrefixSearch } from "../models/FileTagPrefixSearch";
import type { PageSize } from "../models/PageSize";
import type { Paginated_FileSummaryExtended_ } from "../models/Paginated_FileSummaryExtended_";
import type { UploadPart } from "../models/UploadPart";
import type { UploadPartIndex } from "../models/UploadPartIndex";
import type { UploadPartList } from "../models/UploadPartList";
import { request as __request } from "../core/request";

export class FilesService {
  /**
   * Begins a new multipart file upload. Required API key type: 'secret_*' or 'public_*'.
   * @param requestBody File upload parameters.
   * @returns BeginUploadResponse Success.
   * @throws ApiError
   */
  public static async beginMultipartUpload(requestBody: BeginUploadRequest): Promise<BeginUploadResponse> {
    const result = await __request({
      method: "POST",
      path: `/v1/files`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`
      }
    });
    return result.body;
  }

  /**
   * Deletes multiple files. Required API key type: 'secret_*' only.
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async deleteFileBatch(requestBody: DeleteFileBatch): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/files`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Lists the files for a given account. Required API key type: 'secret_*' only.
   * @param accountId
   * @param pageSize
   * @param fileTag
   * @param fileTagPrefixSearch
   * @param backwardToken
   * @param forwardToken
   * @returns Paginated_FileSummaryExtended_ Success.
   * @throws ApiError
   */
  public static async getFiles(
    accountId: AccountId,
    pageSize: PageSize,
    fileTag?: FileTagName,
    fileTagPrefixSearch?: FileTagPrefixSearch,
    backwardToken?: ContinuationToken,
    forwardToken?: ContinuationToken
  ): Promise<Paginated_FileSummaryExtended_> {
    const result = await __request({
      method: "GET",
      path: `/v1/files`,
      query: {
        accountId: accountId,
        pageSize: pageSize,
        fileTag: fileTag,
        fileTagPrefixSearch: fileTagPrefixSearch,
        backwardToken: backwardToken,
        forwardToken: forwardToken
      },
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Finalizes an upload part for an in-progress multipart upload. Required API key type: 'secret_*' or 'public_*'.
   * @param fileId
   * @param uploadPartIndex
   * @param requestBody
   * @returns void
   * @throws ApiError
   */
  public static async completeUploadPart(
    fileId: FileId,
    uploadPartIndex: UploadPartIndex,
    requestBody: CompleteUploadPartRequest
  ): Promise<void> {
    const result = await __request({
      method: "PUT",
      path: `/v1/files/${fileId}/upload_parts/${uploadPartIndex}`,
      body: requestBody,
      mediaType: "application/json",
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File or upload part not found.`
      }
    });
    return result.body;
  }

  /**
   * Gets a remaining upload part for an in-progress upload. Required API key type: 'secret_*' or 'public_*'.
   * @param fileId
   * @param uploadPartIndex
   * @returns UploadPart Success.
   * @throws ApiError
   */
  public static async getUploadPart(fileId: FileId, uploadPartIndex: UploadPartIndex): Promise<UploadPart> {
    const result = await __request({
      method: "GET",
      path: `/v1/files/${fileId}/upload_parts/${uploadPartIndex}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File or upload part not found.`
      }
    });
    return result.body;
  }

  /**
   * Deletes a single file. Required API key type: 'secret_*' only.
   * @param fileId
   * @returns void
   * @throws ApiError
   */
  public static async deleteFile(fileId: FileId): Promise<void> {
    const result = await __request({
      method: "DELETE",
      path: `/v1/files/${fileId}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Gets information about a specific file. Required API key type: 'secret_*' only.
   * @param fileId
   * @returns FileSummaryExtended Success.
   * @throws ApiError
   */
  public static async getFile(fileId: FileId): Promise<FileSummaryExtended> {
    const result = await __request({
      method: "GET",
      path: `/v1/files/${fileId}`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`
      }
    });
    return result.body;
  }

  /**
   * Lists the remaining upload parts for an in-progress upload. An empty array is returned when the upload is complete. Required API key type: 'secret_*' or 'public_*'.
   * @param fileId
   * @returns UploadPartList Success.
   * @throws ApiError
   */
  public static async getUploadParts(fileId: FileId): Promise<UploadPartList> {
    const result = await __request({
      method: "GET",
      path: `/v1/files/${fileId}/upload_parts`,
      errors: {
        401: `Unauthenticated.`,
        403: `Unauthorized.`,
        404: `File not found.`
      }
    });
    return result.body;
  }
}
